function pfs_struct = pfs_open_frames( filePattern, frameSize )
  ## Open frames / image in one of the suppoted formats for reading or
  ## writing. Reading or writting frames is donw with pfsput or pfsget.
  ##
  ## usage: pfs_struct = pfs_open_frames( filePattern, size )
  ##        pfs_struct = pfs_open_frames( filePattern )
  ##
  ## This command is equivalent to pfsopen, but can handle files in any
  ## format supported by pfstools. 'filePattern' can specify files,
  ## frames, including '--frames' and '--skip-missing', similarly as
  ## 'pfsin' / 'pfsout' commands. You can pass also additional options,
  ## like --compression=RLE for exr files in filePattern. 
  ## All option that take an argument (except --frames) must given in
  ## the form --option=value, that is without a space between an
  ## option and its argument.
  ##
  ## pfs_close_frames should be used instead of pfs_close to close pfsstream.
  ##
  
  tmp_name = tmpnam();
  [err msg] = mkfifo( tmp_name, 1023 );
  if( err != 0 )
    error( "pfs_open_frames: %s", msg );
  endif

  doWrite = exist( "frameSize" );
  
  try
    if( doWrite ) 
      execStr = sprintf( "pfsout %s <%s", filePattern, tmp_name );
    else
      execStr = sprintf( "pfsin %s >%s", filePattern, tmp_name );
    endif   
    system( execStr, 0, "async" );

    if( doWrite ) 
      pfs_struct = pfsopen( tmp_name, frameSize );
    else
      pfs_struct = pfsopen( tmp_name );
    endif

    pfs_struct.PIPE=tmp_name;
          
  catch
    unlink( tmp_name );   
    error( [ "pfs_open_frames: " __error_text__ ] );
  end_try_catch      
    
endfunction
